@@ -5,7 +5,7 @@
 #
 # Update:
 #   23-Mar-2011   jdw Added method to rename attributes in category containers.
-#   05-Apr-2011   jdw Change cif writer to select double quoting as preferred 
+#   05-Apr-2011   jdw Change cif writer to select double quoting as preferred
 #                     quoting style where possible.
 #   16-Jan-2012   jdw Create base class for DataCategory class
 #   22-Mar-2012   jdw when append attributes to existing categories update
@@ -47,8 +47,7 @@ import re, sys, traceback
 
 
 class CifName(object):
-    ''' Class of utilities for CIF-style data names -
-    '''
+    """Class of utilities for CIF-style data names -"""
 
     def __init__(self):
         pass
@@ -73,17 +72,16 @@ class CifName(object):
         if i == -1:
             return None
         else:
-            return name[i + 1:]
+            return name[i + 1 :]
 
 
 class ContainerBase(object):
-    ''' Container base class for data and definition objects.
-    '''
+    """Container base class for data and definition objects."""
 
     def __init__(self, name):
         # The enclosing scope of the data container (e.g. data_/save_)
         self.__name = name
-        # List of category names within this container -  
+        # List of category names within this container -
         self.__objNameList = []
         # dictionary of DataCategory objects keyed by category name.
         self.__objCatalog = {}
@@ -117,35 +115,35 @@ class ContainerBase(object):
         return self.__objNameList
 
     def append(self, obj):
-        """ Add the input object to the current object catalog. An existing object
-            of the same name will be overwritten.
+        """Add the input object to the current object catalog. An existing object
+        of the same name will be overwritten.
         """
         if obj.getName() is not None:
             if obj.getName() not in self.__objCatalog:
-                # self.__objNameList is keeping track of object order here -- 
+                # self.__objNameList is keeping track of object order here --
                 self.__objNameList.append(obj.getName())
             self.__objCatalog[obj.getName()] = obj
 
     def replace(self, obj):
-        """ Replace an existing object with the input object
-        """
-        if ((obj.getName() is not None) and (obj.getName() in self.__objCatalog)):
+        """Replace an existing object with the input object"""
+        if (obj.getName() is not None) and (obj.getName() in self.__objCatalog):
             self.__objCatalog[obj.getName()] = obj
 
     def printIt(self, fh=sys.stdout, type="brief"):
-        fh.write("+ %s container: %30s contains %4d categories\n" %
-                 (self.getType(), self.getName(), len(self.__objNameList)))
+        fh.write(
+            "+ %s container: %30s contains %4d categories\n"
+            % (self.getType(), self.getName(), len(self.__objNameList))
+        )
         for nm in self.__objNameList:
             fh.write("--------------------------------------------\n")
             fh.write("Data category: %s\n" % nm)
-            if type == 'brief':
+            if type == "brief":
                 self.__objCatalog[nm].printIt(fh)
             else:
                 self.__objCatalog[nm].dumpIt(fh)
 
     def rename(self, curName, newName):
-        """ Change the name of an object in place -
-        """
+        """Change the name of an object in place -"""
         try:
             i = self.__objNameList.index(curName)
             self.__objNameList[i] = newName
@@ -156,8 +154,7 @@ class ContainerBase(object):
             return False
 
     def remove(self, curName):
-        """ Revmove object by name.  Return True on success or False otherwise.
-        """
+        """Revmove object by name.  Return True on success or False otherwise."""
         try:
             if curName in self.__objCatalog:
                 del self.__objCatalog[curName]
@@ -175,21 +172,23 @@ class ContainerBase(object):
 class DefinitionContainer(ContainerBase):
     def __init__(self, name):
         super(DefinitionContainer, self).__init__(name)
-        self.setType('definition')
+        self.setType("definition")
 
     def isCategory(self):
-        if self.exists('category'):
+        if self.exists("category"):
             return True
         return False
 
     def isAttribute(self):
-        if self.exists('item'):
+        if self.exists("item"):
             return True
         return False
 
     def printIt(self, fh=sys.stdout, type="brief"):
-        fh.write("Definition container: %30s contains %4d categories\n" %
-                 (self.getName(), len(self.getObjNameList())))
+        fh.write(
+            "Definition container: %30s contains %4d categories\n"
+            % (self.getName(), len(self.getObjNameList()))
+        )
         if self.isCategory():
             fh.write("Definition type: category\n")
         elif self.isAttribute():
@@ -200,19 +199,18 @@ class DefinitionContainer(ContainerBase):
         for nm in self.getObjNameList():
             fh.write("--------------------------------------------\n")
             fh.write("Definition category: %s\n" % nm)
-            if type == 'brief':
+            if type == "brief":
                 self.getObj(nm).printIt(fh)
             else:
                 self.getObj(nm).dumpId(fh)
 
 
 class DataContainer(ContainerBase):
-    ''' Container class for DataCategory objects.
-    '''
+    """Container class for DataCategory objects."""
 
     def __init__(self, name):
         super(DataContainer, self).__init__(name)
-        self.setType('data')
+        self.setType("data")
         self.__globalFlag = False
 
     def invokeDataBlockMethod(self, type, method, db):
@@ -227,8 +225,7 @@ class DataContainer(ContainerBase):
 
 
 class DataCategoryBase(object):
-    """ Base object definition for a data category -
-    """
+    """Base object definition for a data category -"""
 
     def __init__(self, name, attributeNameList=None, rowList=None):
         self._name = name
@@ -273,8 +270,7 @@ class DataCategoryBase(object):
 
 
 class DataCategory(DataCategoryBase):
-    """  Methods for creating, accessing, and formatting PDBx cif data categories.  
-    """
+    """Methods for creating, accessing, and formatting PDBx cif data categories."""
 
     def __init__(self, name, attributeNameList=None, rowList=None):
         super(DataCategory, self).__init__(name, attributeNameList, rowList)
@@ -287,32 +283,50 @@ class DataCategory(DataCategoryBase):
         self.__avoidEmbeddedQuoting = False
         #
         # --------------------------------------------------------------------
-        # any whitespace 
+        # any whitespace
         self.__wsRe = re.compile(r"\s")
         self.__wsAndQuotesRe = re.compile(r"[\s'\"]")
         # any newline or carriage control
         self.__nlRe = re.compile(r"[\n\r]")
         #
-        # single quote 
+        # single quote
         self.__sqRe = re.compile(r"[']")
         #
         self.__sqWsRe = re.compile(r"('\s)|(\s')")
 
-        # double quote 
+        # double quote
         self.__dqRe = re.compile(r'["]')
         self.__dqWsRe = re.compile(r'("\s)|(\s")')
         #
-        self.__intRe = re.compile(r'^[0-9]+$')
-        self.__floatRe = re.compile(r'^-?(([0-9]+)[.]?|([0-9]*[.][0-9]+))([(][0-9]+[)])?([eE][+-]?[0-9]+)?$')
+        self.__intRe = re.compile(r"^[0-9]+$")
+        self.__floatRe = re.compile(
+            r"^-?(([0-9]+)[.]?|([0-9]*[.][0-9]+))([(][0-9]+[)])?([eE][+-]?[0-9]+)?$"
+        )
         #
-        self.__dataTypeList = ['DT_NULL_VALUE', 'DT_INTEGER', 'DT_FLOAT', 'DT_UNQUOTED_STRING', 'DT_ITEM_NAME',
-                               'DT_DOUBLE_QUOTED_STRING', 'DT_SINGLE_QUOTED_STRING', 'DT_MULTI_LINE_STRING']
-        self.__formatTypeList = ['FT_NULL_VALUE', 'FT_NUMBER', 'FT_NUMBER', 'FT_UNQUOTED_STRING',
-                                 'FT_QUOTED_STRING', 'FT_QUOTED_STRING', 'FT_QUOTED_STRING', 'FT_MULTI_LINE_STRING']
+        self.__dataTypeList = [
+            "DT_NULL_VALUE",
+            "DT_INTEGER",
+            "DT_FLOAT",
+            "DT_UNQUOTED_STRING",
+            "DT_ITEM_NAME",
+            "DT_DOUBLE_QUOTED_STRING",
+            "DT_SINGLE_QUOTED_STRING",
+            "DT_MULTI_LINE_STRING",
+        ]
+        self.__formatTypeList = [
+            "FT_NULL_VALUE",
+            "FT_NUMBER",
+            "FT_NUMBER",
+            "FT_UNQUOTED_STRING",
+            "FT_QUOTED_STRING",
+            "FT_QUOTED_STRING",
+            "FT_QUOTED_STRING",
+            "FT_MULTI_LINE_STRING",
+        ]
         #
 
     def __getitem__(self, x):
-        """  Implements list-type functionality - 
+        """Implements list-type functionality -
         Implements op[x] for some special cases -
         x=integer - returns the row in category (normal list behavior)
         x=string  - returns the value of attribute 'x' in first row.
@@ -340,7 +354,7 @@ class DataCategory(DataCategoryBase):
         return self._rowList
 
     def getRowCount(self):
-        return (len(self._rowList))
+        return len(self._rowList)
 
     def getRow(self, index):
         try:
@@ -350,7 +364,7 @@ class DataCategory(DataCategoryBase):
 
     def removeRow(self, index):
         try:
-            if ((index >= 0) and (index < len(self._rowList))):
+            if (index >= 0) and (index < len(self._rowList)):
                 del self._rowList[index]
                 if self.__currentRowIndex >= len(self._rowList):
                     self.__currentRowIndex = len(self._rowList) - 1
@@ -363,15 +377,14 @@ class DataCategory(DataCategoryBase):
         return False
 
     def getFullRow(self, index):
-        """ Return a full row based on the length of the the attribute list.
-        """
+        """Return a full row based on the length of the the attribute list."""
         try:
-            if (len(self._rowList[index]) < self._numAttributes):
+            if len(self._rowList[index]) < self._numAttributes:
                 for ii in range(self._numAttributes - len(self._rowList[index])):
-                    self._rowList[index].append('?')
+                    self._rowList[index].append("?")
             return self._rowList[index]
         except:
-            return ['?' for ii in range(self._numAttributes)]
+            return ["?" for ii in range(self._numAttributes)]
 
     def getName(self):
         return self._name
@@ -438,7 +451,7 @@ class DataCategory(DataCategoryBase):
             self._attributeNameList.append(attributeName)
             self._catalog[attributeNameLC] = attributeName
             # add a placeholder to any existing rows for the new attribute.
-            if (len(self._rowList) > 0):
+            if len(self._rowList) > 0:
                 for row in self._rowList:
                     row.append("?")
             #
@@ -481,18 +494,22 @@ class DataCategory(DataCategoryBase):
                 ll = len(self._rowList[rowI])
                 ind = self._attributeNameList.index(attribute)
 
-                # extend the list if needed - 
-                if (ind >= ll):
+                # extend the list if needed -
+                if ind >= ll:
                     self._rowList[rowI].extend([None for ii in range(2 * ind - ll)])
                 self._rowList[rowI][ind] = value
             except (IndexError):
-                self.__lfh.write("DataCategory(setvalue) index error category %s attribute %s index %d value %r\n" %
-                                 (self._name, attribute, rowI, value))
+                self.__lfh.write(
+                    "DataCategory(setvalue) index error category %s attribute %s index %d value %r\n"
+                    % (self._name, attribute, rowI, value)
+                )
                 traceback.print_exc(file=self.__lfh)
                 # raise IndexError
             except (ValueError):
-                self.__lfh.write("DataCategory(setvalue) value error category %s attribute %s index %d value %r\n" %
-                                 (self._name, attribute, rowI, value))
+                self.__lfh.write(
+                    "DataCategory(setvalue) value error category %s attribute %s index %d value %r\n"
+                    % (self._name, attribute, rowI, value)
+                )
                 traceback.print_exc(file=self.__lfh)
                 # raise ValueError
 
@@ -536,7 +553,7 @@ class DataCategory(DataCategoryBase):
 
         for row in self._rowList:
             ll = len(row)
-            if (ind >= ll):
+            if ind >= ll:
                 row.extend([None for ii in range(2 * ind - ll)])
                 row[ind] = None
             exec(method.getInline())
@@ -555,8 +572,7 @@ class DataCategory(DataCategoryBase):
         return mList
 
     def renameAttribute(self, curAttributeName, newAttributeName):
-        """ Change the name of an attribute in place -
-        """
+        """Change the name of an attribute in place -"""
         try:
             i = self._attributeNameList.index(curAttributeName)
             self._attributeNameList[i] = newAttributeName
@@ -568,8 +584,10 @@ class DataCategory(DataCategoryBase):
 
     def printIt(self, fh=sys.stdout):
         fh.write("--------------------------------------------\n")
-        fh.write("  Category: %s attribute list length: %d\n" %
-                 (self._name, len(self._attributeNameList)))
+        fh.write(
+            "  Category: %s attribute list length: %d\n"
+            % (self._name, len(self._attributeNameList))
+        )
         for at in self._attributeNameList:
             fh.write("  Category: %s attribute: %s\n" % (self._name, at))
 
@@ -579,15 +597,22 @@ class DataCategory(DataCategoryBase):
             #
             if len(row) == len(self._attributeNameList):
                 for ii, v in enumerate(row):
-                    fh.write("        %30s: %s ...\n" % (self._attributeNameList[ii], str(v)[:30]))
+                    fh.write(
+                        "        %30s: %s ...\n"
+                        % (self._attributeNameList[ii], str(v)[:30])
+                    )
             else:
-                fh.write("+WARNING - %s data length %d attribute name length %s mismatched\n" %
-                         (self._name, len(row), len(self._attributeNameList)))
+                fh.write(
+                    "+WARNING - %s data length %d attribute name length %s mismatched\n"
+                    % (self._name, len(row), len(self._attributeNameList))
+                )
 
     def dumpIt(self, fh=sys.stdout):
         fh.write("--------------------------------------------\n")
-        fh.write("  Category: %s attribute list length: %d\n" %
-                 (self._name, len(self._attributeNameList)))
+        fh.write(
+            "  Category: %s attribute list length: %d\n"
+            % (self._name, len(self._attributeNameList))
+        )
         for at in self._attributeNameList:
             fh.write("  Category: %s attribute: %s\n" % (self._name, at))
 
@@ -597,122 +622,141 @@ class DataCategory(DataCategoryBase):
                 fh.write("        %30s: %s\n" % (self._attributeNameList[ii], v))
 
     def __formatPdbx(self, inp):
-        """ Format input data following PDBx quoting rules - 
-        """
+        """Format input data following PDBx quoting rules -"""
         try:
-            if (inp is None):
-                return ("?", 'DT_NULL_VALUE')
+            if inp is None:
+                return ("?", "DT_NULL_VALUE")
 
             # pure numerical values are returned as unquoted strings
-            if (isinstance(inp, int) or self.__intRe.search(str(inp))):
-                return ([str(inp)], 'DT_INTEGER')
+            if isinstance(inp, int) or self.__intRe.search(str(inp)):
+                return ([str(inp)], "DT_INTEGER")
 
-            if (isinstance(inp, float) or self.__floatRe.search(str(inp))):
-                return ([str(inp)], 'DT_FLOAT')
+            if isinstance(inp, float) or self.__floatRe.search(str(inp)):
+                return ([str(inp)], "DT_FLOAT")
 
             # null value handling -
 
-            if (inp == "." or inp == "?"):
-                return ([inp], 'DT_NULL_VALUE')
+            if inp == "." or inp == "?":
+                return ([inp], "DT_NULL_VALUE")
 
-            if (inp == ""):
-                return (["."], 'DT_NULL_VALUE')
+            if inp == "":
+                return (["."], "DT_NULL_VALUE")
 
             # Contains white space or quotes ?
             if not self.__wsAndQuotesRe.search(inp):
                 if inp.startswith("_"):
-                    return (self.__doubleQuotedList(inp), 'DT_ITEM_NAME')
+                    return (self.__doubleQuotedList(inp), "DT_ITEM_NAME")
                 else:
-                    return ([str(inp)], 'DT_UNQUOTED_STRING')
+                    return ([str(inp)], "DT_UNQUOTED_STRING")
             else:
                 if self.__nlRe.search(inp):
-                    return (self.__semiColonQuotedList(inp), 'DT_MULTI_LINE_STRING')
+                    return (self.__semiColonQuotedList(inp), "DT_MULTI_LINE_STRING")
                 else:
-                    if (self.__avoidEmbeddedQuoting):
+                    if self.__avoidEmbeddedQuoting:
                         # change priority to choose double quoting where possible.
-                        if not self.__dqRe.search(inp) and not self.__sqWsRe.search(inp):
-                            return (self.__doubleQuotedList(inp), 'DT_DOUBLE_QUOTED_STRING')
-                        elif not self.__sqRe.search(inp) and not self.__dqWsRe.search(inp):
-                            return (self.__singleQuotedList(inp), 'DT_SINGLE_QUOTED_STRING')
+                        if not self.__dqRe.search(inp) and not self.__sqWsRe.search(
+                            inp
+                        ):
+                            return (
+                                self.__doubleQuotedList(inp),
+                                "DT_DOUBLE_QUOTED_STRING",
+                            )
+                        elif not self.__sqRe.search(inp) and not self.__dqWsRe.search(
+                            inp
+                        ):
+                            return (
+                                self.__singleQuotedList(inp),
+                                "DT_SINGLE_QUOTED_STRING",
+                            )
                         else:
-                            return (self.__semiColonQuotedList(inp), 'DT_MULTI_LINE_STRING')
+                            return (
+                                self.__semiColonQuotedList(inp),
+                                "DT_MULTI_LINE_STRING",
+                            )
                     else:
                         # change priority to choose double quoting where possible.
                         if not self.__dqRe.search(inp):
-                            return (self.__doubleQuotedList(inp), 'DT_DOUBLE_QUOTED_STRING')
+                            return (
+                                self.__doubleQuotedList(inp),
+                                "DT_DOUBLE_QUOTED_STRING",
+                            )
                         elif not self.__sqRe.search(inp):
-                            return (self.__singleQuotedList(inp), 'DT_SINGLE_QUOTED_STRING')
+                            return (
+                                self.__singleQuotedList(inp),
+                                "DT_SINGLE_QUOTED_STRING",
+                            )
                         else:
-                            return (self.__semiColonQuotedList(inp), 'DT_MULTI_LINE_STRING')
-
+                            return (
+                                self.__semiColonQuotedList(inp),
+                                "DT_MULTI_LINE_STRING",
+                            )
 
         except:
             traceback.print_exc(file=self.__lfh)
 
     def __dataTypePdbx(self, inp):
-        """ Detect the PDBx data type - 
-        """
-        if (inp is None):
-            return ('DT_NULL_VALUE')
+        """Detect the PDBx data type -"""
+        if inp is None:
+            return "DT_NULL_VALUE"
 
         # pure numerical values are returned as unquoted strings
         if isinstance(inp, int) or self.__intRe.search(str(inp)):
-            return ('DT_INTEGER')
+            return "DT_INTEGER"
 
         if isinstance(inp, float) or self.__floatRe.search(str(inp)):
-            return ('DT_FLOAT')
+            return "DT_FLOAT"
 
         # null value handling -
 
-        if (inp == "." or inp == "?"):
-            return ('DT_NULL_VALUE')
+        if inp == "." or inp == "?":
+            return "DT_NULL_VALUE"
 
-        if (inp == ""):
-            return ('DT_NULL_VALUE')
+        if inp == "":
+            return "DT_NULL_VALUE"
 
         # Contains white space or quotes ?
         if not self.__wsAndQuotesRe.search(inp):
             if inp.startswith("_"):
-                return ('DT_ITEM_NAME')
+                return "DT_ITEM_NAME"
             else:
-                return ('DT_UNQUOTED_STRING')
+                return "DT_UNQUOTED_STRING"
         else:
             if self.__nlRe.search(inp):
-                return ('DT_MULTI_LINE_STRING')
+                return "DT_MULTI_LINE_STRING"
             else:
-                if (self.__avoidEmbeddedQuoting):
+                if self.__avoidEmbeddedQuoting:
                     if not self.__sqRe.search(inp) and not self.__dqWsRe.search(inp):
-                        return ('DT_DOUBLE_QUOTED_STRING')
+                        return "DT_DOUBLE_QUOTED_STRING"
                     elif not self.__dqRe.search(inp) and not self.__sqWsRe.search(inp):
-                        return ('DT_SINGLE_QUOTED_STRING')
+                        return "DT_SINGLE_QUOTED_STRING"
                     else:
-                        return ('DT_MULTI_LINE_STRING')
+                        return "DT_MULTI_LINE_STRING"
                 else:
                     if not self.__sqRe.search(inp):
-                        return ('DT_DOUBLE_QUOTED_STRING')
+                        return "DT_DOUBLE_QUOTED_STRING"
                     elif not self.__dqRe.search(inp):
-                        return ('DT_SINGLE_QUOTED_STRING')
+                        return "DT_SINGLE_QUOTED_STRING"
                     else:
-                        return ('DT_MULTI_LINE_STRING')
+                        return "DT_MULTI_LINE_STRING"
 
     def __singleQuotedList(self, inp):
         l = []
         l.append("'")
         l.append(inp)
         l.append("'")
-        return (l)
+        return l
 
     def __doubleQuotedList(self, inp):
         l = []
         l.append('"')
         l.append(inp)
         l.append('"')
-        return (l)
+        return l
 
     def __semiColonQuotedList(self, inp):
         l = []
         l.append("\n")
-        if inp[-1] == '\n':
+        if inp[-1] == "\n":
             l.append(";")
             l.append(inp)
             l.append(";")
@@ -724,7 +768,7 @@ class DataCategory(DataCategoryBase):
             l.append(";")
             l.append("\n")
 
-        return (l)
+        return l
 
     def getValueFormatted(self, attributeName=None, rowIndex=None):
         if attributeName is None:
@@ -739,10 +783,15 @@ class DataCategory(DataCategoryBase):
 
         if isinstance(attribute, str) and isinstance(rowI, int):
             try:
-                list, type = self.__formatPdbx(self._rowList[rowI][self._attributeNameList.index(attribute)])
+                list, type = self.__formatPdbx(
+                    self._rowList[rowI][self._attributeNameList.index(attribute)]
+                )
                 return "".join(list)
             except IndexError:
-                self.__lfh.write("attributeName %s rowI %r rowdata %r\n" % (attributeName, rowI, self._rowList[rowI]))
+                self.__lfh.write(
+                    "attributeName %s rowI %r rowdata %r\n"
+                    % (attributeName, rowI, self._rowList[rowI])
+                )
                 raise IndexError()
         raise TypeError(attribute)
 
@@ -763,7 +812,9 @@ class DataCategory(DataCategoryBase):
 
     def getFormatTypeList(self, steps=1):
         try:
-            curDataTypeList = ['DT_NULL_VALUE' for i in range(len(self._attributeNameList))]
+            curDataTypeList = [
+                "DT_NULL_VALUE" for i in range(len(self._attributeNameList))
+            ]
             for row in self._rowList[::steps]:
                 for indx in range(len(self._attributeNameList)):
                     val = row[indx]
@@ -783,12 +834,15 @@ class DataCategory(DataCategoryBase):
                 ii = self.__dataTypeList.index(dt)
                 curFormatTypeList.append(self.__formatTypeList[ii])
         except:
-            self.__lfh.write("PdbxDataCategory(getFormatTypeList) ++Index error at index %d in row %r\n" % (indx, row))
+            self.__lfh.write(
+                "PdbxDataCategory(getFormatTypeList) ++Index error at index %d in row %r\n"
+                % (indx, row)
+            )
 
         return curFormatTypeList, curDataTypeList
 
     def getFormatTypeListX(self):
-        curDataTypeList = ['DT_NULL_VALUE' for i in range(len(self._attributeNameList))]
+        curDataTypeList = ["DT_NULL_VALUE" for i in range(len(self._attributeNameList))]
         for row in self._rowList:
             for indx in range(len(self._attributeNameList)):
                 val = row[indx]
