@@ -6,11 +6,12 @@
 from moleculekit.projections.projection import Projection
 import numpy as np
 import logging
+
 logger = logging.getLogger(__name__)
 
 
 class MetricTMscore(Projection):
-    """ Calculates the TMscore of a set of trajectories to a reference structure
+    """Calculates the TMscore of a set of trajectories to a reference structure
 
     Parameters
     ----------
@@ -26,24 +27,25 @@ class MetricTMscore(Projection):
         Atom selection string around which to center the wrapping of the trajectories.
         See more `here <http://www.ks.uiuc.edu/Research/vmd/vmd-1.9.2/ug/node89.html>`__
     """
+
     def __init__(self, refmol, trajtmstr, reftmstr=None):
         super().__init__()
 
         if reftmstr is None:
             reftmstr = trajtmstr
         self._refmol = refmol
-        self._reftmsel = self._refmol.atomselect(reftmstr) & (self._refmol.name == 'CA')
+        self._reftmsel = self._refmol.atomselect(reftmstr) & (self._refmol.name == "CA")
         self._trajtmsel = trajtmstr
 
-    def _calculateMolProp(self, mol, props='all'):
+    def _calculateMolProp(self, mol, props="all"):
         res = {}
-        res['trajtmsel'] = mol.atomselect(self._trajtmsel) & (mol.name == 'CA')
-        if np.sum(res['trajtmsel']) == 0:
-            raise RuntimeError('RMSD atom selection resulted in 0 atoms.')
+        res["trajtmsel"] = mol.atomselect(self._trajtmsel) & (mol.name == "CA")
+        if np.sum(res["trajtmsel"]) == 0:
+            raise RuntimeError("RMSD atom selection resulted in 0 atoms.")
         return res
 
     def project(self, mol):
-        """ Project molecule.
+        """Project molecule.
 
         Parameters
         ----------
@@ -56,14 +58,15 @@ class MetricTMscore(Projection):
             An array containing the projected data.
         """
         from moleculekit.util import molTMscore
+
         mol = mol.copy()
-        trajtmsel = self._getMolProp(mol, 'trajtmsel')
+        trajtmsel = self._getMolProp(mol, "trajtmsel")
 
         tm, _ = molTMscore(mol, self._refmol, trajtmsel, self._reftmsel)
         return tm[:, np.newaxis]
 
     def getMapping(self, mol):
-        """ Returns the description of each projected dimension.
+        """Returns the description of each projected dimension.
 
         Parameters
         ----------
@@ -75,15 +78,20 @@ class MetricTMscore(Projection):
         map : :class:`DataFrame <pandas.core.frame.DataFrame>` object
             A DataFrame containing the descriptions of each dimension
         """
-        trajtmsel = self._getMolProp(mol, 'trajtmsel')
+        trajtmsel = self._getMolProp(mol, "trajtmsel")
         from pandas import DataFrame
-        types = ['tmscore']
+
+        types = ["tmscore"]
         indexes = [np.where(trajtmsel)[0]]
-        description = ['TMscore to reference structure.']
-        return DataFrame({'type': types, 'atomIndexes': indexes, 'description': description})
+        description = ["TMscore to reference structure."]
+        return DataFrame(
+            {"type": types, "atomIndexes": indexes, "description": description}
+        )
 
 
 import unittest
+
+
 class _TestMetricTMscore(unittest.TestCase):
     def test_tmscore(self):
         from moleculekit.molecule import Molecule
@@ -91,20 +99,46 @@ class _TestMetricTMscore(unittest.TestCase):
         import numpy as np
         from os import path
 
-        mol = Molecule(path.join(home(dataDir='test-projections'), 'trajectory', 'filtered.pdb'))
-        mol.read(path.join(home(dataDir='test-projections'), 'trajectory', 'traj.xtc'))
+        mol = Molecule(
+            path.join(home(dataDir="test-projections"), "trajectory", "filtered.pdb")
+        )
+        mol.read(path.join(home(dataDir="test-projections"), "trajectory", "traj.xtc"))
         ref = mol.copy()
 
         ref.dropFrames(keep=0)
-        mol.dropFrames(keep=np.arange(mol.numFrames-20, mol.numFrames))
+        mol.dropFrames(keep=np.arange(mol.numFrames - 20, mol.numFrames))
 
-        metr = MetricTMscore(ref, 'protein and name CA')
+        metr = MetricTMscore(ref, "protein and name CA")
         data = metr.project(mol)
 
-        lasttm = np.array([0.9633381, 0.96441294, 0.96553609, 0.96088852, 0.96288511, 0.95677591, 0.96544727, 0.96359811,
-                        0.95658912, 0.96893117, 0.96623924, 0.96064913, 0.96207041, 0.95947848, 0.96657048, 0.95993426,
-                        0.96543296, 0.96806875, 0.96437248, 0.96144066], dtype=np.float32)
-        assert np.all(np.abs(data.flatten() - lasttm) < 0.001), 'TMscore calculation is broken'
+        lasttm = np.array(
+            [
+                0.9633381,
+                0.96441294,
+                0.96553609,
+                0.96088852,
+                0.96288511,
+                0.95677591,
+                0.96544727,
+                0.96359811,
+                0.95658912,
+                0.96893117,
+                0.96623924,
+                0.96064913,
+                0.96207041,
+                0.95947848,
+                0.96657048,
+                0.95993426,
+                0.96543296,
+                0.96806875,
+                0.96437248,
+                0.96144066,
+            ],
+            dtype=np.float32,
+        )
+        assert np.all(
+            np.abs(data.flatten() - lasttm) < 0.001
+        ), "TMscore calculation is broken"
 
 
 if __name__ == "__main__":
