@@ -92,8 +92,7 @@ class _TestSmallMol(unittest.TestCase):
         self.assertEqual(
             n_atoms,
             LIGAND_N_ATOMS,
-            "Atoms not correctly loaded. "
-            "Expected: {}; Now: {}".format(LIGAND_N_ATOMS, n_atoms),
+            f"Atoms not correctly loaded. Expected: {LIGAND_N_ATOMS}; Now: {n_atoms}",
         )
 
     def test_loadSmile(self):
@@ -103,8 +102,7 @@ class _TestSmallMol(unittest.TestCase):
         self.assertEqual(
             n_atoms,
             SMILE_N_ATOMS,
-            "Atoms not correctly loaded. "
-            "Expected: {}; Now: {}".format(SMILE_N_ATOMS, n_atoms),
+            f"Atoms not correctly loaded. Expected: {SMILE_N_ATOMS}; Now: {n_atoms}",
         )
 
     def test_getAtoms(self):
@@ -143,8 +141,7 @@ class _TestSmallMol(unittest.TestCase):
         self.assertListEqual(
             details,
             CHIRAL_DETAILS,
-            "chiral atom does not match."
-            "Expected: {}; Now: {}".format(CHIRAL_DETAILS, details),
+            f"chiral atom does not match.Expected: {CHIRAL_DETAILS}; Now: {details}",
         )
 
     def test_foundBond(self):
@@ -217,7 +214,7 @@ class _TestSmallMol(unittest.TestCase):
         from moleculekit.molecule import mol_equal
 
         sm = SmallMol(self.benzamidine_mol2)
-        mol = sm.toMolecule(formalcharges=False)
+        mol = sm.toMolecule()
 
         assert mol_equal(sm, mol, exceptFields=["serial", "name"], _logger=False)
 
@@ -227,7 +224,9 @@ class _TestSmallMol(unittest.TestCase):
         mol = Molecule(self.benzamidine_mol2)
         sm = SmallMol(mol)
 
-        assert mol_equal(sm, mol, exceptFields=["serial", "name"], _logger=False)
+        assert mol_equal(
+            sm, mol, exceptFields=["serial", "name", "formalcharge"], _logger=False
+        )
 
         mol = Molecule(self.indole_mol2)
         sm = SmallMol(mol, force_reading=True)
@@ -254,39 +253,6 @@ class _TestSmallMol(unittest.TestCase):
             msg="The bonds type are not the same of the reference",
         )
 
-    @unittest.skipIf(
-        rdkit.__version__ == "2019.03.4", "new rdkit versions break 2D depiction"
-    )
-    def test_depict(self):
-        import IPython
-
-        refimg = os.path.join(self.dataDir, "benzamidine.svg")
-
-        sm = SmallMol(self.benzamidine_mol2)
-
-        img_name = NamedTemporaryFile().name + ".svg"
-        sm.depict(sketch=True, filename=img_name, atomlabels="%a%i%c")
-        png_name = NamedTemporaryFile().name + ".png"
-        sm.depict(sketch=True, filename=png_name, atomlabels="%a%i%c")
-        noext_name = NamedTemporaryFile().name
-        sm.depict(sketch=True, filename=noext_name, atomlabels="%a%i%c")
-        sm.depict(sketch=False, optimize=True)
-        _img = sm.depict(sketch=True, ipython=True)
-
-        refimg_size = os.path.getsize(refimg)
-        sm_img_size = os.path.getsize(img_name)
-
-        self.assertIsInstance(
-            _img,
-            IPython.core.display.SVG,
-            msg="The object is not an IPython image as expected",
-        )
-        self.assertEqual(
-            sm_img_size,
-            refimg_size,
-            msg="The svg image does not have the same size of the reference",
-        )
-
     def test_repr(self):
         sm = SmallMol(self.benzamidine_mol2)
         _ = str(sm)
@@ -295,14 +261,14 @@ class _TestSmallMol(unittest.TestCase):
         sm = SmallMol(self.benzamidine_mol2)
         assert (
             sm.toSMILES() == "NC(=[NH2+])C1=CC=CC=C1"
-        ), "Failed with SMILES: {}".format(sm.toSMILES())
+        ), f"Failed with SMILES: {sm.toSMILES()}"
 
     def test_toSMARTS(self):
         sm = SmallMol(self.benzamidine_mol2)
         assert (
             sm.toSMARTS()
             == "[#6]1(:[#6H]:[#6H]:[#6H]:[#6H]:[#6H]:1)-[#6](=[#7H2+])-[#7H2]"
-        ), "Failed with SMARTS: {}".format(sm.toSMARTS())
+        ), f"Failed with SMARTS: {sm.toSMARTS()}"
 
     def test_align(self):
         from moleculekit.util import rotationMatrix
