@@ -9,91 +9,45 @@ import os
 from moleculekit.support import xtc_lib
 from moleculekit.util import ensurelist
 import networkx as nx
-import collections
 import logging
 import numbers
 
 logger = logging.getLogger(__name__)
 
 # fmt: off
+first_col_elements = {
+    'Se', 'Sr', 'Gd', 'Mn', 'Pt', 'Cs', 'Mg', 'Be', 'Sb', 'Bi', 'Th', 'Yb',
+    'Zn', 'Kr', 'Rb', 'Ar', 'Pa', 'Fe', 'Ag', 'In', 'Eu', 'Hg', 'Pr', 'Al',
+    'Ru', 'Sm', 'Ba', 'Lu', 'Re', 'Xe', 'Dy', 'Ti', 'As', 'Pu', 'Ir', 'Br',
+    'Li', 'Pd', 'Ce', 'Cr', 'Ho', 'La', 'Sn', 'Te', 'Cl', 'Hf', 'Ga', 'Co',
+    'Os', 'Tl', 'Au', 'Sc', 'Tb', 'Zr', 'Cu', 'Rh', 'Er', 'Mo', 'Si', 'Ca',
+    'Ta', 'Cm', 'Am', 'Na', 'Pb', 'Ni', 'Ne', 'Cd'
+}
 
-_Pair = collections.namedtuple('Atom', 'resname name')
-# The following is taken from MDAnalysis to align atom names based on the strict PDB formatting.
-# Some programs like AutoDock require this strict formatting to guess atom types.
-
-# These attributes are used to deduce how to format the atom name.
-_ions_metals = ('FE', 'AS', 'ZN', 'MG', 'MN', 'CO', 'BR',
-                'CU', 'TA', 'MO', 'AL', 'BE', 'SE', 'PT',
-                'EU', 'NI', 'IR', 'RH', 'AU', 'GD', 'RU', 
-                'XE', 'RB', 'LU', 'GA', 'BA', 'CS', 'Y',
-                'PB', 'SM', 'SR', 'YB')
-
-# Mercurial can be confused for hydrogen gamma. Yet, mercurial is
-# rather rare in the PDB. Here are all the residues that contain
-# mercurial.
-_special_hg = ('CMH', 'EMC', 'MBO', 'MMC', 'HGB', 'BE7', 'PMB')
-# Chloride can be confused for a carbon. Here are the residues that
-# contain chloride.
-_special_cl = ('0QE', 'CPT', 'DCE', 'EAA', 'IMN', 'OCZ', 'OMY', 'OMZ',
-               'UN9', '1N1', '2T8', '393', '3MY', 'BMU', 'CLM', 'CP6',
-               'DB8', 'DIF', 'EFZ', 'LUR', 'RDC', 'UCL', 'XMM', 'HLT',
-               'IRE', 'LCP', 'PCI', 'VGH')
-# In these pairs, the atom name is aligned on the first column
-# (column 13).
-_include_pairs = (_Pair('OEC', 'CA1'),
-                  _Pair('PLL', 'PD'),
-                  _Pair('OEX', 'CA1'))
-# In these pairs, the atom name is aligned on the second column
-# (column 14), but other rules would align them on the first column.
-_exclude_pairs = (_Pair('C14', 'C14'), _Pair('C15', 'C15'),
-                  _Pair('F9F', 'F9F'), _Pair('OAN', 'OAN'),
-                  _Pair('BLM', 'NI'), _Pair('BZG', 'CO'),
-                  _Pair('BZG', 'NI'), _Pair('VNL', 'CO1'),
-                  _Pair('VNL', 'CO2'), _Pair('PF5', 'FE1'),
-                  _Pair('PF5', 'FE2'), _Pair('UNL', 'UNL'))
+metals_ions = {
+    'FE', 'AS', 'ZN', 'MG', 'MN', 'CO', 'BR', 'CU', 'TA', 'MO', 'AL', 'BE',
+    'SE', 'PT', 'EU', 'NI', 'IR', 'RH', 'AU', 'GD', 'RU', 'XE', 'RB', 'LU',
+    'GA', 'BA', 'CS', 'PB', 'SM', 'SR', 'YB', 'Y'
+}
 
 _rename_elements = {('SOD', 'SO'): 'Na'}
-
-# After scanning most of the PDB database these are the most common elements which start on position 12
-_position_12_elements = ['Se', 'Sr', 'Gd', 'Mn', 'Pt', 'Cs', 'Mg', 'Be', 'Sb', 'Bi', 'Th', 'Yb', 
-                         'Zn', 'Kr', 'Rb', 'Ar', 'Pa', 'Fe', 'Ag', 'In', 'Eu', 'Hg', 
-                         'Pr', 'Al', 'Ru', 'Sm', 'Ba', 'Lu', 'Re', 'Xe', 'Dy', 'Ti', 'As', 'Pu', 'Ir', 
-                         'Br', 'Li', 'Pd', 'Ce', 'Cr', 'Ho', 'La', 'Sn', 'Te', 'Cl', 'Hf', 'Ga', 
-                         'Co', 'Os', 'Tl', 'Au', 'Sc', 'Tb', 'Zr', 'Cu', 'Rh', 'Er', 'Mo', 'Si', 
-                         'Ca', 'Ta', 'Cm', 'Am', 'Na', 'Pb', 'Ni', 'Ne', 'Cd']
-
 # fmt: on
 
 
-def _deduce_PDB_atom_name(name, resname, element=None):
-    """Deduce how the atom name should be aligned.
-    Atom name format can be deduced from the atom type, yet atom type is
-    not always available. This function uses the atom name and residue name
-    to deduce how the atom name should be formatted. The rules in use got
-    inferred from an analysis of the PDB. See gist at
-    <https://gist.github.com/jbarnoud/37a524330f29b5b7b096> for more
-    details.
-    """
-    if (
-        element is not None
-        and (element.strip().capitalize() in _position_12_elements)
-        and (name[0:2].upper() == element[0:2].upper())
-    ):
-        return f"{name:<4}"
-    if len(name) >= 4:
-        return name[:4]
-    elif len(name) == 1:
-        return f" {name}  "
-    elif (
-        resname == name
-        or name[:2] in _ions_metals
-        or name == "UNK"
-        or (resname in _special_hg and name[:2] == "HG")
-        or (resname in _special_cl and name[:2] == "CL")
-        or _Pair(resname, name) in _include_pairs
-    ) and _Pair(resname, name) not in _exclude_pairs:
-        return f"{name:<4}"
-    return f" {name:<3}"
+def _format_pdb_name(name, resname, element=None):
+    name = name[:4]
+    first_col = f"{name:<4}"
+    second_col = f" {name:<3}"
+
+    element_matched = False
+    if element is not None:
+        in_elements = element.strip().capitalize() in first_col_elements
+        same_name_elem = name[0:2].upper() == element[0:2].upper()
+        element_matched = in_elements and same_name_elem
+
+    if name == resname or len(name) == 4 or element_matched or name[:2] in metals_ions:
+        return first_col
+    return second_col
 
 
 def _getPDBElement(name, element, lowersecond=True):
@@ -213,42 +167,46 @@ def PDBwrite(mol, filename, frames=None, writebonds=True, mode="pdb"):
             % (box[0], box[1], box[2], 90, 90, 90)
         )
 
+    if mode == "pdb":
+        linefmt = "{!s:6.6}{!s:>5.5} {}{!s:>1.1}{!s:4.4}{!s:>1.1}{!s:>4.4}{!s:>1.1}   {}{}{}{}{}      {!s:4.4}{!s:>2.2}{!s:>2.2}\n"
+    elif mode == "pdbqt":
+        linefmt = "{!s:6.6}{!s:>5.5} {}{!s:>1.1}{!s:4.4}{!s:>1.1}{!s:>4.4}{!s:>1.1}   {}{}{}{}{}    {:>6.3f} {!s:<2.2}  \n"
+    else:
+        raise AssertionError("Invalid mode for PDB writer")
+
     for f in range(numFrames):
         fh.write("MODEL    %5d\n" % (frames[f] + 1))
         for i in range(0, len(mol.record)):
-            name = _deduce_PDB_atom_name(mol.name[i], mol.resname[i], mol.element[i])
+            name = _format_pdb_name(mol.name[i], mol.resname[i], mol.element[i])
+
+            data = [
+                mol.record[i],
+                serial[i],
+                name,
+                mol.altloc[i],
+                mol.resname[i],
+                mol.chain[i],
+                mol.resid[i],
+                mol.insertion[i],
+                f"{coords[i, 0, f]:8.3f}"[:8],
+                f"{coords[i, 1, f]:8.3f}"[:8],
+                f"{coords[i, 2, f]:8.3f}"[:8],
+                f"{mol.occupancy[i]:6.2f}"[:6],
+                f"{mol.beta[i]:6.2f}"[:6],
+            ]
 
             if mode == "pdb":
-                linefmt = "{!s:6.6}{!s:>5.5} {}{!s:>1.1}{!s:4.4}{!s:>1.1}{!s:>4.4}{!s:>1.1}   {}{}{}{}{}      {!s:4.4}{!s:>2.2}  \n"
-                prelast = mol.segid[i]
-                last = mol.element[i].upper()
+                formalcharge = ""
+                if mol.formalcharge[i] > 0:
+                    formalcharge = f"{int(mol.formalcharge[i])}+"
+                elif mol.formalcharge[i] < 0:
+                    formalcharge = f"{abs(int(mol.formalcharge[i]))}-"
+                data += [mol.segid[i], mol.element[i].upper(), formalcharge]
             elif mode == "pdbqt":
-                linefmt = "{!s:6.6}{!s:>5.5} {}{!s:>1.1}{!s:4.4}{!s:>1.1}{!s:>4.4}{!s:>1.1}   {}{}{}{}{}    {:>6.3f} {!s:<2.2}  \n"
-                prelast = mol.charge[i]
-                last = mol.atomtype[i]
-            else:
-                raise AssertionError("Invalid mode for PDB writer")
+                data += [mol.charge[i], mol.atomtype[i]]
+
+            fh.write(linefmt.format(*data))
 
-            fh.write(
-                linefmt.format(
-                    mol.record[i],
-                    serial[i],
-                    name,
-                    mol.altloc[i],
-                    mol.resname[i],
-                    mol.chain[i],
-                    mol.resid[i],
-                    mol.insertion[i],
-                    f"{coords[i, 0, f]:8.3f}"[:8],
-                    f"{coords[i, 1, f]:8.3f}"[:8],
-                    f"{coords[i, 2, f]:8.3f}"[:8],
-                    f"{mol.occupancy[i]:6.2f}"[:6],
-                    f"{mol.beta[i]:6.2f}"[:6],
-                    prelast,
-                    last,
-                )
-            )
-            # TODO : convert charges to ints if we ever write them
             if i < len(mol.record) - 1 and mol.segid[i] != mol.segid[i + 1]:
                 fh.write("TER\n")
 
@@ -620,6 +578,11 @@ def MOL2write(mol, filename, explicitbonds=None):
 def SDFwrite(mol, filename):
     import datetime
 
+    if any(mol.bondtype == "un"):
+        raise RuntimeError(
+            "Cannot write 'un' bond types to SDF. Please specify the molecule bond orders."
+        )
+
     mol2bonds = {"1": 1, "2": 2, "3": 3, "ar": 4, "4": 4}
     with open(filename, "w", encoding="ascii") as fh:
         fh.write(f"{mol.viewname}\n")
@@ -753,6 +716,116 @@ def MDTRAJwrite(mol, filename):
         raise ValueError(f'MDtraj reader failed for file {filename} with error "{e}"')
 
 
+def CIFwrite(mol, filename):
+    from moleculekit.pdbx.reader.PdbxContainers import DataContainer, DataCategory
+    from moleculekit.pdbx.writer.PdbxWriter import PdbxWriter
+
+    single_mol = len(np.unique(mol.resname)) == 1
+    if not len(mol.resname[0]):
+        raise RuntimeError("Please specify a resname for your molecule.")
+
+    atom_site_mapping = {
+        "group_PDB": "record",
+        "id": "serial",
+        "type_symbol": "element",
+        "label_alt_id": "altloc",
+        "label_entity_id": "segid",
+        "pdbx_PDB_ins_code": "insertion",
+        "Cartn_x": "coords",
+        "Cartn_y": "coords",
+        "Cartn_z": "coords",
+        "occupancy": "occupancy",
+        "B_iso_or_equiv": "beta",
+        "pdbx_formal_charge": "formalcharge",
+        "auth_seq_id": "resid",
+        "auth_comp_id": "resname",
+        "auth_asym_id": "chain",
+        "auth_atom_id": "name",
+        "pdbx_PDB_model_num": "frame",
+    }
+    chem_comp_mapping = {
+        "comp_id": "resname",
+        "atom_id": "name",
+        "alt_atom_id": "name",
+        "type_symbol": "element",
+        "charge": "formalcharge",
+        "model_Cartn_x": "coords",
+        "model_Cartn_y": "coords",
+        "model_Cartn_z": "coords",
+        "pdbx_model_Cartn_x_ideal": "coords",
+        "pdbx_model_Cartn_y_ideal": "coords",
+        "pdbx_model_Cartn_z_ideal": "coords",
+    }
+    bondtype_map = {"1": "SING", "2": "DOUB", "3": "TRIP"}
+    xyz_map = {
+        "Cartn_x": 0,
+        "Cartn_y": 1,
+        "Cartn_z": 2,
+        "model_Cartn_x": 0,
+        "model_Cartn_y": 1,
+        "model_Cartn_z": 2,
+        "pdbx_model_Cartn_x_ideal": 0,
+        "pdbx_model_Cartn_y_ideal": 1,
+        "pdbx_model_Cartn_z_ideal": 2,
+    }
+
+    mapping = atom_site_mapping
+    atom_block = "atom_site"
+    if single_mol:
+        if len(np.unique(mol.name)) != mol.numAtoms:
+            raise RuntimeError(
+                "Atom names need to be unique to write small molecule CIF file"
+            )
+        mapping = chem_comp_mapping
+        atom_block = "chem_comp_atom"
+
+    myDataList = []
+    with open(filename, "w") as ofh:
+        curContainer = DataContainer(mol.resname[0])
+        if atom_block == "chem_comp_atom":
+            aCat = DataCategory("chem_comp")
+            aCat.appendAttribute("id")
+            aCat.appendAttribute("type")
+            aCat.appendAttribute("pdbx_formal_charge")
+            aCat.append([mol.resname[0], "NON-POLYMER", int(mol.formalcharge.sum())])
+            curContainer.append(aCat)
+
+        aCat = DataCategory(atom_block)
+        for at in mapping:
+            aCat.appendAttribute(at)
+
+        for i in range(mol.numAtoms):
+            data = []
+            for at in mapping:
+                if mapping[at] == "coords":
+                    data.append("{:.3f}".format(mol.coords[i, xyz_map[at], mol.frame]))
+                elif mapping[at] == "frame":
+                    data.append(1)
+                else:
+                    data.append(mol.__dict__[mapping[at]][i])
+            aCat.append(data)
+        curContainer.append(aCat)
+
+        if single_mol:
+            bCat = DataCategory("chem_comp_bond")
+            for at in ["comp_id", "atom_id_1", "atom_id_2", "value_order"]:
+                bCat.appendAttribute(at)
+            for i in range(mol.bonds.shape[0]):
+                bCat.append(
+                    [
+                        mol.resname[0],
+                        mol.name[mol.bonds[i][0]],
+                        mol.name[mol.bonds[i][1]],
+                        bondtype_map[mol.bondtype[i]],
+                    ]
+                )
+            curContainer.append(bCat)
+
+        myDataList.append(curContainer)
+        pdbxW = PdbxWriter(ofh)
+        pdbxW.write(myDataList)
+
+
 _WRITERS = {
     "psf": PSFwrite,
     "pdb": PDBwrite,
@@ -764,6 +837,7 @@ _WRITERS = {
     "coor": BINCOORwrite,
     "xtc": XTCwrite,
     "xsc": XSCwrite,
+    "cif": CIFwrite,
 }
 
 
@@ -841,11 +915,13 @@ class _TestWriters(unittest.TestCase):
                 except UnicodeDecodeError:
                     print(f"Could not compare file {reffile} due to not being unicode")
                     continue
+
+                print("Testing file", reffile, tmpfile)
                 with open(reffile, "r") as f:
                     reflines = f.readlines()
                     if ext == "sdf":
                         reflines = reflines[2:]
-                print("Testing file", reffile, tmpfile)
+
                 self.assertEqual(
                     filelines, reflines, msg=f"Failed comparison of {reffile} {tmpfile}"
                 )
